| Title: | A Shared Resource Interface for Bigmemory Project Packages |
|---|---|
| Description: | A shared resource interface for the bigmemory and synchronicity packages. |
| Authors: | Michael J. Kane [aut, cre]
|
| Maintainer: | Michael J. Kane <[email protected]> |
| License: | LGPL-3 | Apache License 2.0 |
| Version: | 0.1.8 |
| Built: | 2026-06-05 09:05:52 UTC |
| Source: | https://github.com/cran/bigmemory.sri |
This generic function should be used to attach to a system-wide shared resource on a computer. It is used by other packages.
attach.resource(obj, ...)attach.resource(obj, ...)
obj |
a descriptor object describing the location and type of a shared resource. |
... |
other information needed for object-specific attaching. |
An R object that makes use of a share resource.
# Create a concrete function. setMethod( "attach.resource", signature(obj = "NULL"), function (obj, ...) { NULL } ) # Describe it attach.resource(NULL)# Create a concrete function. setMethod( "attach.resource", signature(obj = "NULL"), function (obj, ...) { NULL } ) # Describe it attach.resource(NULL)
This generic function should be used for creating a
description of a shared resource and is used in conjunction with
attach.resource() to utilize shared resources from an R session.
describe(x)describe(x)
x |
the object to create the descriptor for. |
A user-defined description of a shared resource.
[bigmemory.sri::attach.resource()]
# Create a concrete function. setMethod( "describe", signature(x = "list"), function (x) { print(x$value) } ) # Create an object to describe. tst = list(loc = "in_ram_not_shared", value = "hello world") # Describe it describe(tst)# Create a concrete function. setMethod( "describe", signature(x = "list"), function (x) { print(x$value) } ) # Create an object to describe. tst = list(loc = "in_ram_not_shared", value = "hello world") # Describe it describe(tst)